summaryrefslogtreecommitdiffstats
path: root/admin
diff options
context:
space:
mode:
authorramon <ramongomez@us.es>2016-05-19 09:41:44 +0000
committerramon <ramongomez@us.es>2016-05-19 09:41:44 +0000
commit1485b9918a8e3041c69ae27ab944df27dde8f894 (patch)
tree0926cf4cb8691fab4b1227dfc714967b72ce35ee /admin
parentbbc672f1ab20c0f7a6896846709ff2e2483787f1 (diff)
#708: Usar parámetros {{{id}}} y {{{name}}} en lista de UOs.
git-svn-id: https://opengnsys.es/svn/branches/version1.1@4939 a21b9725-9963-47de-94b9-378ad31fedc9
Diffstat (limited to 'admin')
-rw-r--r--admin/WebConsole/rest/index.php2
-rw-r--r--admin/WebConsole/rest/server.php10
2 files changed, 6 insertions, 6 deletions
diff --git a/admin/WebConsole/rest/index.php b/admin/WebConsole/rest/index.php
index edc2c479..c6487a05 100644
--- a/admin/WebConsole/rest/index.php
+++ b/admin/WebConsole/rest/index.php
@@ -7,7 +7,7 @@
* @license GNU GPLv3+
* @author Ramón M. Gómez, ETSII Univ. Sevilla
* @version 1.1
- * @date 2015-04-16
+ * @date 2016-05-19
*/
// Inclussion files.
diff --git a/admin/WebConsole/rest/server.php b/admin/WebConsole/rest/server.php
index aca8e00e..08d00bb5 100644
--- a/admin/WebConsole/rest/server.php
+++ b/admin/WebConsole/rest/server.php
@@ -7,7 +7,7 @@
* @license GNU GPLv3+
* @author Ramón M. Gómez, ETSII Univ. Sevilla
* @version 1.1
- * @date 2015-04-16
+ * @date 2016-05-19
*/
@@ -218,7 +218,7 @@ $app->post('/login',
* @brief List all defined Organizational Units
* @note Route: /ous, Method: GET
* @param no
* @return JSON array with ouid, ouname for every defined OU
*/
$app->get('/ous', 'validateApiKey', function() {
global $cmd;
@@ -231,8 +231,8 @@ $app->get('/ous', 'validateApiKey', function() {
$rs->Primero();
while (!$rs->EOF) {
$tmp = array();
- $tmp['ouid'] = $rs->campos["idcentro"];
- $tmp['ouname'] = $rs->campos["nombrecentro"];
+ $tmp['id'] = $rs->campos["idcentro"];
+ $tmp['name'] = $rs->campos["nombrecentro"];
array_push($response['ous'], $tmp);
$rs->Siguiente();
}
@@ -245,7 +245,7 @@ $app->get('/ous', 'validateApiKey', function() {
* @brief Get Organizational Unit data
* @note Route: /ous/id, Method: GET
* @param id OU id.
- * @return JSON string with ouid, ouname and description
+ * @return JSON string with OU's parameters
*/
$app->get('/ous/:ouid', 'validateApiKey',
function($ouid) {
@@ -218,7 +218,7 @@ $app->post('/login',
* @note Route: /ous, Method: GET
* @param no
- * @return JSON array with ouid, ouname for every defined OU
+ * @return JSON array with id. and name for every defined OU
*/
$app->get('/ous', 'validateApiKey', function() {